==> taler-exchange-0.12.0.tar.gz: taler-exchange-0.12.0/src/auditordb/pg_insert_purse_not_closed_inconsistencies.c <==
/*
   This file is part of TALER
   Copyright (C) 2024 Taler Systems SA

   TALER is free software; you can redistribute it and/or modify it under the
   terms of the GNU General Public License as published by the Free Software
   Foundation; either version 3, or (at your option) any later version.

   TALER is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
   A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along with
   TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */


#include "platform.h"
#include "taler_pq_lib.h"
#include "pg_helper.h"

#include "pg_insert_purse_not_closed_inconsistencies.h"

enum GNUNET_DB_QueryStatus
TAH_PG_insert_purse_not_closed_inconsistencies (
  void *cls,
  const struct TALER_AUDITORDB_PurseNotClosedInconsistencies *dc)
{
  struct PostgresClosure *pg = cls;
  struct GNUNET_PQ_QueryParam params[] = {

    GNUNET_PQ_query_param_auto_from_type (&dc->purse_pub),
    TALER_PQ_query_param_amount (pg->conn, &dc->amount),
    GNUNET_PQ_query_param_absolute_time (&dc->expiration_date),

    GNUNET_PQ_query_param_end
  };

  PREPARE (pg,
           "auditor_purse_not_closed_inconsistencies_insert",
           "INSERT INTO auditor_purse_not_closed_inconsistencies "
           "(purse_pub"
           ",amount"
           ",expiration_date"
           ") VALUES ($1,$2,$3)"
           " ON CONFLICT (purse_pub) DO UPDATE"
           " SET amount = excluded.amount,"
           " expiration_date = excluded.expiration_date,"
           " suppressed = false;"
           );
  return GNUNET_PQ_eval_prepared_non_select (pg->conn,
                                             "auditor_purse_not_closed_inconsistencies_insert",
                                             params);
}

==> taler-exchange-0.14.1.tar.gz: taler-exchange-0.14.1/src/auditordb/pg_insert_purse_not_closed_inconsistencies.c <==
/*
   This file is part of TALER
   Copyright (C) 2024 Taler Systems SA

   TALER is free software; you can redistribute it and/or modify it under the
   terms of the GNU General Public License as published by the Free Software
   Foundation; either version 3, or (at your option) any later version.

   TALER is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
   A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along with
   TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */
#include "platform.h"
#include "taler_pq_lib.h"
#include "pg_helper.h"
#include "pg_insert_purse_not_closed_inconsistencies.h"


enum GNUNET_DB_QueryStatus
TAH_PG_insert_purse_not_closed_inconsistencies (
  void *cls,
  const struct TALER_AUDITORDB_PurseNotClosedInconsistencies *dc)
{
  struct PostgresClosure *pg = cls;
  struct GNUNET_PQ_QueryParam params[] = {
    GNUNET_PQ_query_param_auto_from_type (&dc->purse_pub),
    TALER_PQ_query_param_amount (pg->conn,
                                 &dc->amount),
    GNUNET_PQ_query_param_absolute_time (&dc->expiration_date),
    GNUNET_PQ_query_param_end
  };

  PREPARE (pg,
           "auditor_purse_not_closed_inconsistencies_insert",
           "INSERT INTO auditor_purse_not_closed_inconsistencies "
           "(purse_pub"
           ",amount"
           ",expiration_date"
           ") VALUES ($1,$2,$3)"
           );
  return GNUNET_PQ_eval_prepared_non_select (pg->conn,
                                             "auditor_purse_not_closed_inconsistencies_insert",
                                             params);
}
